package de.intevation.artifactdatabase.state;

import de.intevation.artifacts.Artifact;

import java.util.HashMap;
import java.util.Map;

public interface FacetActivity
{
    public static final FacetActivity ACTIVE = new FacetActivity() {
        @Override
        public boolean isInitialActive(
            Artifact artifact,
            Facet    facet,
            String   output
        ) {
            return true;
        }
    };

    public static final FacetActivity INACTIVE = new FacetActivity() {
        @Override
        public boolean isInitialActive(
            Artifact artifact,
            Facet    facet,
            String   output
        ) {
            return false;
        }
    };

    boolean isInitialActive(Artifact artifact, Facet facet, String output);

    public static final class Registry {

        private static final Registry INSTANCE = new Registry();

        private Map<String, FacetActivity> activities;

        private Registry() {
            activities = new HashMap<String, FacetActivity>();
        }

        public static Registry getInstance() {
            return INSTANCE;
        }

        public synchronized FacetActivity getActivity(String key) {
            FacetActivity activity = activities.get(key);
            return activity != null ? activity : ACTIVE;
        }

        public synchronized void register(String key, FacetActivity activity) {
            activities.put(key, activity);
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
